Module: ResqueLogger::ClassMethods

Included in:
Resque
Defined in:
lib/resque_logger.rb

Instance Method Summary collapse

Instance Method Details

#logger_configObject



8
9
10
# File 'lib/resque_logger.rb', line 8

def logger_config
  @logger_config
end

#logger_config=(options) ⇒ Object

Configures ResqueLogger with the following hash:

folder: <folder location for logs>,
class_name: <class name to be created>,
class_args: <an array of class arguments to be passed in constructor>,
level: <logger level>,
formatter: <a new instance of formatter class to add in logger>

Hash keys will be symbols to work.



24
25
26
27
28
# File 'lib/resque_logger.rb', line 24

def logger_config=(options)
  check_logger_args! options

  @logger_config = options
end